Hubbell regression This function mimics the GLM structure. We do so to avoid conflicts with the current glm implementation (if it gets updated)
Source:R/HubbellGLM.R
HubbellGLM.RdHubbell regression This function mimics the GLM structure. We do so to avoid conflicts with the current glm implementation (if it gets updated)
Arguments
- formula
Same as
stats::glm- family
a member of the hubbell family for
glm.fit.hubbell.- data
Same as
stats::glm- weights
Same as
stats::glm- subset
Same as
stats::glm- na.action
Same as
stats::glm- start
Same as
stats::glm- etastart
Same as
stats::glm- mustart
Same as
stats::glm- offset
Same as
stats::glm- control
Same as
stats::glm- model
Same as
stats::glm- x
Same as
stats::glm- y
Same as
stats::glm- singular.ok
Same as
stats::glm- contrasts
Same as
stats::glm- ...
Same as
stats::glm