Simulate the number of distinct species from a Dirichlet process
Source:R/rDPspecies.R
rDPspecies.RdDraws the number of distinct species \(Y^{(n)}\) from the Dirichlet process prior with concentration parameter \(\alpha\) and sample size \(n\).